from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TrashFolderTypeField(str, Enum):
    FOLDER = 'folder'


class TrashFolderPathCollectionEntriesTypeField(str, Enum):
    FOLDER = 'folder'


class TrashFolderPathCollectionEntriesField(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        *,
        type: Optional[TrashFolderPathCollectionEntriesTypeField] = None,
        id: Optional[str] = None,
        sequence_id: Optional[str] = None,
        etag: Optional[str] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The value will always be `folder`., defaults to None
        :type type: Optional[TrashFolderPathCollectionEntriesTypeField], optional
        :param id: The unique identifier that represent a folder., defaults to None
        :type id: Optional[str], optional
        :param sequence_id: This field is null for the Trash folder., defaults to None
        :type sequence_id: Optional[str], optional
        :param etag: This field is null for the Trash folder., defaults to None
        :type etag: Optional[str], optional
        :param name: The name of the Trash folder., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.sequence_id = sequence_id
        self.etag = etag
        self.name = name


class TrashFolderPathCollectionField(BaseObject):
    def __init__(
        self,
        total_count: int,
        entries: List[TrashFolderPathCollectionEntriesField],
        **kwargs
    ):
        """
        :param total_count: The number of folders in this list.
        :type total_count: int
        :param entries: Array of folders for this item's path collection.
        :type entries: List[TrashFolderPathCollectionEntriesField]
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.entries = entries


class TrashFolderItemStatusField(str, Enum):
    ACTIVE = 'active'
    TRASHED = 'trashed'
    DELETED = 'deleted'


class TrashFolder(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        name: str,
        description: str,
        size: int,
        path_collection: TrashFolderPathCollectionField,
        created_by: UserMini,
        modified_by: UserMini,
        owned_by: UserMini,
        item_status: TrashFolderItemStatusField,
        *,
        etag: Optional[str] = None,
        type: TrashFolderTypeField = TrashFolderTypeField.FOLDER,
        sequence_id: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        trashed_at: Optional[DateTime] = None,
        purged_at: Optional[DateTime] = None,
        content_created_at: Optional[DateTime] = None,
        content_modified_at: Optional[DateTime] = None,
        shared_link: Optional[str] = None,
        folder_upload_email: Optional[str] = None,
        parent: Optional[FolderMini] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting a folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folders/123`
        the `folder_id` is `123`.
                :type id: str
                :param name: The name of the folder.
                :type name: str
                :param size: The folder size in bytes.

        Be careful parsing this integer as its
        value can get very large.
                :type size: int
                :param item_status: Defines if this item has been deleted or not.

        * `active` when the item has is not in the trash
        * `trashed` when the item has been moved to the trash but not deleted
        * `deleted` when the item has been permanently deleted.
                :type item_status: TrashFolderItemStatusField
                :param etag: The HTTP `etag` of this folder. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the folder if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `folder`., defaults to TrashFolderTypeField.FOLDER
                :type type: TrashFolderTypeField, optional
                :param created_at: The date and time when the folder was created. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: The date and time when the folder was last updated. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param trashed_at: The time at which this folder was put in the trash., defaults to None
                :type trashed_at: Optional[DateTime], optional
                :param purged_at: The time at which this folder is expected to be purged
        from the trash., defaults to None
                :type purged_at: Optional[DateTime], optional
                :param content_created_at: The date and time at which this folder was originally
        created., defaults to None
                :type content_created_at: Optional[DateTime], optional
                :param content_modified_at: The date and time at which this folder was last updated., defaults to None
                :type content_modified_at: Optional[DateTime], optional
                :param shared_link: The shared link for this folder. This will
        be `null` if a folder has been trashed, since the link will no longer
        be active., defaults to None
                :type shared_link: Optional[str], optional
                :param folder_upload_email: The folder upload email for this folder. This will
        be `null` if a folder has been trashed, since the upload will no longer
        work., defaults to None
                :type folder_upload_email: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.name = name
        self.description = description
        self.size = size
        self.path_collection = path_collection
        self.created_by = created_by
        self.modified_by = modified_by
        self.owned_by = owned_by
        self.item_status = item_status
        self.etag = etag
        self.type = type
        self.sequence_id = sequence_id
        self.created_at = created_at
        self.modified_at = modified_at
        self.trashed_at = trashed_at
        self.purged_at = purged_at
        self.content_created_at = content_created_at
        self.content_modified_at = content_modified_at
        self.shared_link = shared_link
        self.folder_upload_email = folder_upload_email
        self.parent = parent



from typing import Optional


class ProxyConfig:
    def __init__(
        self,
        url: str,
        *,
        username: Optional[str] = None,
        password: Optional[str] = None
    ):
        self.url = url
        self.username = username
        self.password = password



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingPartnerItemTeamsTypeField(str, Enum):
    CHANNEL = 'channel'
    TEAM = 'team'


class IntegrationMappingPartnerItemTeams(BaseObject):
    _discriminator = 'type', {'channel', 'team'}

    def __init__(
        self,
        type: IntegrationMappingPartnerItemTeamsTypeField,
        id: str,
        tenant_id: str,
        **kwargs
    ):
        """
        :param type: Type of the mapped item referenced in `id`.
        :type type: IntegrationMappingPartnerItemTeamsTypeField
        :param id: ID of the mapped item (of type referenced in `type`).
        :type id: str
        :param tenant_id: ID of the tenant that is registered with Microsoft Teams.
        :type tenant_id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id
        self.tenant_id = tenant_id



from typing import Union

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_extract_structured import AiAgentExtractStructured

from box_sdk_gen.box.errors import BoxSDKError

AiExtractStructuredAgent = Union[AiAgentReference, AiAgentExtractStructured]



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldInformationBarrierReportDetailsDetailsField(BaseObject):
    def __init__(self, *, folder_id: Optional[str] = None, **kwargs):
        """
        :param folder_id: Folder ID for locating this report., defaults to None
        :type folder_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.folder_id = folder_id


class ShieldInformationBarrierReportDetails(BaseObject):
    def __init__(
        self,
        *,
        details: Optional[ShieldInformationBarrierReportDetailsDetailsField] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.details = details



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestCancelRequest(BaseObject):
    def __init__(self, *, reason: Optional[str] = None, **kwargs):
        """
        :param reason: An optional reason for cancelling the sign request., defaults to None
        :type reason: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.reason = reason



from enum import Enum

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.schemas.ai_agent_allowed_entity import AiAgentAllowedEntity

from box_sdk_gen.schemas.ai_studio_agent_ask import AiStudioAgentAsk

from box_sdk_gen.schemas.ai_studio_agent_text_gen import AiStudioAgentTextGen

from box_sdk_gen.schemas.ai_studio_agent_extract import AiStudioAgentExtract

from box_sdk_gen.schemas.ai_multiple_agent_response import AiMultipleAgentResponse

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.ai_single_agent_response_full import AiSingleAgentResponseFull

from box_sdk_gen.schemas.create_ai_agent import CreateAiAgent

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateAiAgentType(str, Enum):
    AI_AGENT = 'ai_agent'


class UpdateAiAgentByIdType(str, Enum):
    AI_AGENT = 'ai_agent'


class AiStudioManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_ai_agents(
        self,
        *,
        mode: Optional[List[str]] = None,
        fields: Optional[List[str]] = None,
        agent_state: Optional[List[str]] = None,
        include_box_default: Optional[bool] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiMultipleAgentResponse:
        """
        Lists AI agents based on the provided parameters.
        :param mode: The mode to filter the agent config to return. Possible values are: `ask`, `text_gen`, and `extract`., defaults to None
        :type mode: Optional[List[str]], optional
        :param fields: The fields to return in the response., defaults to None
        :type fields: Optional[List[str]], optional
        :param agent_state: The state of the agents to return. Possible values are: `enabled`, `disabled` and `enabled_for_selected_users`., defaults to None
        :type agent_state: Optional[List[str]], optional
        :param include_box_default: Whether to include the Box default agents in the response., defaults to None
        :type include_box_default: Optional[bool], optional
        :param marker: Defines the position marker at which to begin returning results., defaults to None
        :type marker: Optional[str], optional
        :param limit: The maximum number of items to return per page., defaults to None
        :type limit: Optional[int], optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'mode': to_string(mode),
                'fields': to_string(fields),
                'agent_state': to_string(agent_state),
                'include_box_default': to_string(include_box_default),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/ai_agents']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiMultipleAgentResponse)

    def create_ai_agent(
        self,
        name: str,
        access_state: str,
        *,
        type: CreateAiAgentType = CreateAiAgentType.AI_AGENT,
        icon_reference: Optional[str] = None,
        allowed_entities: Optional[List[AiAgentAllowedEntity]] = None,
        ask: Optional[AiStudioAgentAsk] = None,
        text_gen: Optional[AiStudioAgentTextGen] = None,
        extract: Optional[AiStudioAgentExtract] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiSingleAgentResponseFull:
        """
                Creates an AI agent. At least one of the following capabilities must be provided: `ask`, `text_gen`, `extract`.
                :param name: The name of the AI Agent.
                :type name: str
                :param access_state: The state of the AI Agent. Possible values are: `enabled`, `disabled`, and `enabled_for_selected_users`.
                :type access_state: str
                :param type: The type of agent used to handle queries., defaults to CreateAiAgentType.AI_AGENT
                :type type: CreateAiAgentType, optional
                :param icon_reference: The icon reference of the AI Agent. It should have format of the URL `https://cdn01.boxcdn.net/app-assets/aistudio/avatars/<file_name>`
        where possible values of `file_name` are: `logo_boxAi.png`,`logo_stamp.png`,`logo_legal.png`,`logo_finance.png`,`logo_config.png`,`logo_handshake.png`,`logo_analytics.png`,`logo_classification.png`., defaults to None
                :type icon_reference: Optional[str], optional
                :param allowed_entities: List of allowed users or groups., defaults to None
                :type allowed_entities: Optional[List[AiAgentAllowedEntity]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'type': type,
            'name': name,
            'access_state': access_state,
            'icon_reference': icon_reference,
            'allowed_entities': allowed_entities,
            'ask': ask,
            'text_gen': text_gen,
            'extract': extract,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/ai_agents']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiSingleAgentResponseFull)

    def update_ai_agent_by_id(
        self,
        agent_id: str,
        name: str,
        access_state: str,
        *,
        type: UpdateAiAgentByIdType = UpdateAiAgentByIdType.AI_AGENT,
        icon_reference: Optional[str] = None,
        allowed_entities: Optional[List[AiAgentAllowedEntity]] = None,
        ask: Optional[AiStudioAgentAsk] = None,
        text_gen: Optional[AiStudioAgentTextGen] = None,
        extract: Optional[AiStudioAgentExtract] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiSingleAgentResponseFull:
        """
                Updates an AI agent.
                :param agent_id: The ID of the agent to update.
        Example: "1234"
                :type agent_id: str
                :param name: The name of the AI Agent.
                :type name: str
                :param access_state: The state of the AI Agent. Possible values are: `enabled`, `disabled`, and `enabled_for_selected_users`.
                :type access_state: str
                :param type: The type of agent used to handle queries., defaults to UpdateAiAgentByIdType.AI_AGENT
                :type type: UpdateAiAgentByIdType, optional
                :param icon_reference: The icon reference of the AI Agent. It should have format of the URL `https://cdn01.boxcdn.net/app-assets/aistudio/avatars/<file_name>`
        where possible values of `file_name` are: `logo_boxAi.png`,`logo_stamp.png`,`logo_legal.png`,`logo_finance.png`,`logo_config.png`,`logo_handshake.png`,`logo_analytics.png`,`logo_classification.png`., defaults to None
                :type icon_reference: Optional[str], optional
                :param allowed_entities: List of allowed users or groups., defaults to None
                :type allowed_entities: Optional[List[AiAgentAllowedEntity]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'type': type,
            'name': name,
            'access_state': access_state,
            'icon_reference': icon_reference,
            'allowed_entities': allowed_entities,
            'ask': ask,
            'text_gen': text_gen,
            'extract': extract,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/ai_agents/',
                        to_string(agent_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiSingleAgentResponseFull)

    def get_ai_agent_by_id(
        self,
        agent_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiSingleAgentResponseFull:
        """
                Gets an AI Agent using the `agent_id` parameter.
                :param agent_id: The agent id to get.
        Example: "1234"
                :type agent_id: str
                :param fields: The fields to return in the response., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/ai_agents/',
                        to_string(agent_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiSingleAgentResponseFull)

    def delete_ai_agent_by_id(
        self, agent_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes an AI agent using the provided parameters.
                :param agent_id: The ID of the agent to delete.
        Example: "1234"
                :type agent_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/ai_agents/',
                        to_string(agent_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_request_update_request import (
    FileRequestUpdateRequestStatusField,
)

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.file_request_update_request import FileRequestUpdateRequest

from box_sdk_gen.box.errors import BoxSDKError


class FileRequestCopyRequestFolderTypeField(str, Enum):
    FOLDER = 'folder'


class FileRequestCopyRequestFolderField(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: Optional[FileRequestCopyRequestFolderTypeField] = None,
        **kwargs
    ):
        """
                :param id: The ID of the folder to associate the new
        file request to.
                :type id: str
                :param type: The value will always be `folder`., defaults to None
                :type type: Optional[FileRequestCopyRequestFolderTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class FileRequestCopyRequest(FileRequestUpdateRequest):
    def __init__(
        self,
        folder: FileRequestCopyRequestFolderField,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        status: Optional[FileRequestUpdateRequestStatusField] = None,
        is_email_required: Optional[bool] = None,
        is_description_required: Optional[bool] = None,
        expires_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
                :param folder: The folder to associate the new file request to.
                :type folder: FileRequestCopyRequestFolderField
                :param title: An optional new title for the file request. This can be
        used to change the title of the file request.

        This will default to the value on the existing file request., defaults to None
                :type title: Optional[str], optional
                :param description: An optional new description for the file request. This can be
        used to change the description of the file request.

        This will default to the value on the existing file request., defaults to None
                :type description: Optional[str], optional
                :param status: An optional new status of the file request.

        When the status is set to `inactive`, the file request
        will no longer accept new submissions, and any visitor
        to the file request URL will receive a `HTTP 404` status
        code.

        This will default to the value on the existing file request., defaults to None
                :type status: Optional[FileRequestUpdateRequestStatusField], optional
                :param is_email_required: Whether a file request submitter is required to provide
        their email address.

        When this setting is set to true, the Box UI will show
        an email field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_email_required: Optional[bool], optional
                :param is_description_required: Whether a file request submitter is required to provide
        a description of the files they are submitting.

        When this setting is set to true, the Box UI will show
        a description field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_description_required: Optional[bool], optional
                :param expires_at: The date after which a file request will no longer accept new
        submissions.

        After this date, the `status` will automatically be set to
        `inactive`.

        This will default to the value on the existing file request., defaults to None
                :type expires_at: Optional[DateTime], optional
        """
        super().__init__(
            title=title,
            description=description,
            status=status,
            is_email_required=is_email_required,
            is_description_required=is_description_required,
            expires_at=expires_at,
            **kwargs
        )
        self.folder = folder



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class HubItemV2025R0TypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'
    WEB_LINK = 'web_link'


class HubItemV2025R0(BaseObject):
    _discriminator = 'type', {'file', 'folder', 'web_link'}

    def __init__(self, id: str, type: HubItemV2025R0TypeField, name: str, **kwargs):
        """
        :param id: The unique identifier for this item.
        :type id: str
        :param type: The type of the item.
        :type type: HubItemV2025R0TypeField
        :param name: The name of the item.
        :type name: str
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name



from typing import Union

from box_sdk_gen.schemas.v2025_r0.shield_list_content_country_v2025_r0 import (
    ShieldListContentCountryV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.shield_list_content_domain_v2025_r0 import (
    ShieldListContentDomainV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.shield_list_content_email_v2025_r0 import (
    ShieldListContentEmailV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.shield_list_content_ip_v2025_r0 import (
    ShieldListContentIpV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.shield_list_content_integration_v2025_r0 import (
    ShieldListContentIntegrationV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

ShieldListContentV2025R0 = Union[
    ShieldListContentCountryV2025R0,
    ShieldListContentDomainV2025R0,
    ShieldListContentEmailV2025R0,
    ShieldListContentIpV2025R0,
    ShieldListContentIntegrationV2025R0,
]



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class ExternalCollabSecuritySettingsV2025R0(BaseObject):
    def __init__(
        self,
        *,
        denylist_domains: Optional[List[str]] = None,
        denylist_emails: Optional[List[str]] = None,
        allowlist_domains: Optional[List[str]] = None,
        allowlist_emails: Optional[List[str]] = None,
        state: Optional[str] = None,
        scheduled_status: Optional[str] = None,
        scheduled_at: Optional[DateTime] = None,
        factor_type_settings: Optional[str] = None,
        **kwargs
    ):
        """
        :param denylist_domains: List of domains that are not allowed for external collaboration. Applies if state is `denylist`., defaults to None
        :type denylist_domains: Optional[List[str]], optional
        :param denylist_emails: List of email addresses that are not allowed for external collaboration. Applies if state is `denylist`., defaults to None
        :type denylist_emails: Optional[List[str]], optional
        :param allowlist_domains: List of domains that are allowed for external collaboration. Applies if state is `allowlist`., defaults to None
        :type allowlist_domains: Optional[List[str]], optional
        :param allowlist_emails: List of email addresses that are allowed for external collaboration. Applies if state is `allowlist`., defaults to None
        :type allowlist_emails: Optional[List[str]], optional
        :param state: The state of the external collaboration security settings. Possible values include `enabled`, `disabled`, `allowlist`, and `denylist`., defaults to None
        :type state: Optional[str], optional
        :param scheduled_status: The status of the scheduling to apply external collaboration security settings. Possible values include `in_progress`, `scheduled`, `completed`, `failed`, and `scheduled_immediate`., defaults to None
        :type scheduled_status: Optional[str], optional
        :param scheduled_at: Scheduled at., defaults to None
        :type scheduled_at: Optional[DateTime], optional
        :param factor_type_settings: Factor type for the external collaborators authentication. Possible values include `totp`, `any`, or `unknown`., defaults to None
        :type factor_type_settings: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.denylist_domains = denylist_domains
        self.denylist_emails = denylist_emails
        self.allowlist_domains = allowlist_domains
        self.allowlist_emails = allowlist_emails
        self.state = state
        self.scheduled_status = scheduled_status
        self.scheduled_at = scheduled_at
        self.factor_type_settings = factor_type_settings



from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.user_reference_v2025_r0 import UserReferenceV2025R0

from box_sdk_gen.box.errors import BoxSDKError


class ExternalUsersSubmitDeleteJobRequestV2025R0(BaseObject):
    def __init__(self, external_users: List[UserReferenceV2025R0], **kwargs):
        """
        :param external_users: List of external users to delete.
        :type external_users: List[UserReferenceV2025R0]
        """
        super().__init__(**kwargs)
        self.external_users = external_users



from typing import Union

from typing import List

from box_sdk_gen.schemas.metadata_field_filter_float_range import (
    MetadataFieldFilterFloatRange,
)

from box_sdk_gen.schemas.metadata_field_filter_date_range import (
    MetadataFieldFilterDateRange,
)

from box_sdk_gen.box.errors import BoxSDKError

MetadataFilterValue = Union[
    str, float, List[str], MetadataFieldFilterFloatRange, MetadataFieldFilterDateRange
]



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.legal_hold_policy_assignment import LegalHoldPolicyAssignment

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FileVersionLegalHoldTypeField(str, Enum):
    FILE_VERSION_LEGAL_HOLD = 'file_version_legal_hold'


class FileVersionLegalHold(BaseObject):
    _discriminator = 'type', {'file_version_legal_hold'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[FileVersionLegalHoldTypeField] = None,
        file_version: Optional[FileVersionMini] = None,
        file: Optional[FileMini] = None,
        legal_hold_policy_assignments: Optional[List[LegalHoldPolicyAssignment]] = None,
        deleted_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this file version legal hold., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `file_version_legal_hold`., defaults to None
                :type type: Optional[FileVersionLegalHoldTypeField], optional
                :param legal_hold_policy_assignments: List of assignments contributing to this Hold., defaults to None
                :type legal_hold_policy_assignments: Optional[List[LegalHoldPolicyAssignment]], optional
                :param deleted_at: Time that this File-Version-Legal-Hold was
        deleted., defaults to None
                :type deleted_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.file_version = file_version
        self.file = file
        self.legal_hold_policy_assignments = legal_hold_policy_assignments
        self.deleted_at = deleted_at



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputSsnValidationValidationTypeField(str, Enum):
    SSN = 'ssn'


class SignRequestSignerInputSsnValidation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: SignRequestSignerInputSsnValidationValidationTypeField = SignRequestSignerInputSsnValidationValidationTypeField.SSN,
        **kwargs
    ):
        """
        :param validation_type: Validates that the text input is a Social Security Number (SSN)., defaults to SignRequestSignerInputSsnValidationValidationTypeField.SSN
        :type validation_type: SignRequestSignerInputSsnValidationValidationTypeField, optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_text_gen import AiAgentTextGen

from box_sdk_gen.schemas.ai_dialogue_history import AiDialogueHistory

from box_sdk_gen.schemas.ai_text_gen_agent import AiTextGenAgent

from box_sdk_gen.box.errors import BoxSDKError


class AiTextGenItemsTypeField(str, Enum):
    FILE = 'file'


class AiTextGenItemsField(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        id: str,
        *,
        type: AiTextGenItemsTypeField = AiTextGenItemsTypeField.FILE,
        content: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The ID of the item.
        :type id: str
        :param type: The type of the item., defaults to AiTextGenItemsTypeField.FILE
        :type type: AiTextGenItemsTypeField, optional
        :param content: The content to use as context for generating new text or editing existing text., defaults to None
        :type content: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.content = content


class AiTextGen(BaseObject):
    def __init__(
        self,
        prompt: str,
        items: List[AiTextGenItemsField],
        *,
        dialogue_history: Optional[List[AiDialogueHistory]] = None,
        ai_agent: Optional[AiTextGenAgent] = None,
        **kwargs
    ):
        """
                :param prompt: The prompt provided by the client to be answered by the LLM. The prompt's length is limited to 10000 characters.
                :type prompt: str
                :param items: The items to be processed by the LLM, often files.
        The array can include **exactly one** element.

        **Note**: Box AI handles documents with text representations up to 1MB in size.
        If the file size exceeds 1MB, the first 1MB of text representation will be processed.
                :type items: List[AiTextGenItemsField]
                :param dialogue_history: The history of prompts and answers previously passed to the LLM. This parameter provides the additional context to the LLM when generating the response., defaults to None
                :type dialogue_history: Optional[List[AiDialogueHistory]], optional
        """
        super().__init__(**kwargs)
        self.prompt = prompt
        self.items = items
        self.dialogue_history = dialogue_history
        self.ai_agent = ai_agent



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.integration_mapping_base import IntegrationMappingBaseTypeField

from box_sdk_gen.schemas.integration_mapping_base import IntegrationMappingBase

from box_sdk_gen.schemas.integration_mapping_partner_item_teams import (
    IntegrationMappingPartnerItemTeams,
)

from box_sdk_gen.schemas.folder_reference import FolderReference

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class IntegrationMappingTeamsIntegrationTypeField(str, Enum):
    TEAMS = 'teams'


class IntegrationMappingTeams(IntegrationMappingBase):
    def __init__(
        self,
        partner_item: IntegrationMappingPartnerItemTeams,
        box_item: FolderReference,
        id: str,
        *,
        integration_type: Optional[IntegrationMappingTeamsIntegrationTypeField] = None,
        is_overridden_by_manual_mapping: Optional[bool] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        type: IntegrationMappingBaseTypeField = IntegrationMappingBaseTypeField.INTEGRATION_MAPPING,
        **kwargs
    ):
        """
                :param partner_item: Mapped item object for Teams.
                :type partner_item: IntegrationMappingPartnerItemTeams
                :param id: A unique identifier of a folder mapping
        (part of a composite key together
        with `integration_type`).
                :type id: str
                :param integration_type: Identifies the Box partner app,
        with which the mapping is associated.
        Supports Slack and Teams.
        (part of the composite key together with `id`)., defaults to None
                :type integration_type: Optional[IntegrationMappingTeamsIntegrationTypeField], optional
                :param is_overridden_by_manual_mapping: Identifies whether the mapping has
        been manually set by the team owner from UI for channels
        (as opposed to being automatically created)., defaults to None
                :type is_overridden_by_manual_mapping: Optional[bool], optional
                :param created_at: When the integration mapping object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the integration mapping object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param type: Mapping type., defaults to IntegrationMappingBaseTypeField.INTEGRATION_MAPPING
                :type type: IntegrationMappingBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.partner_item = partner_item
        self.box_item = box_item
        self.integration_type = integration_type
        self.is_overridden_by_manual_mapping = is_overridden_by_manual_mapping
        self.created_at = created_at
        self.modified_at = modified_at



from typing import Optional

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_base import (
    ShieldInformationBarrierSegmentRestrictionBaseTypeField,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_base import (
    ShieldInformationBarrierSegmentRestrictionBase,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_mini import (
    ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_mini import (
    ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField,
)

from box_sdk_gen.schemas.shield_information_barrier_segment_restriction_mini import (
    ShieldInformationBarrierSegmentRestrictionMini,
)

from box_sdk_gen.schemas.shield_information_barrier_base import (
    ShieldInformationBarrierBase,
)

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class ShieldInformationBarrierSegmentRestriction(
    ShieldInformationBarrierSegmentRestrictionMini
):
    def __init__(
        self,
        shield_information_barrier_segment: ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField,
        restricted_segment: ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField,
        *,
        shield_information_barrier: Optional[ShieldInformationBarrierBase] = None,
        created_at: Optional[DateTime] = None,
        created_by: Optional[UserBase] = None,
        updated_at: Optional[DateTime] = None,
        updated_by: Optional[UserBase] = None,
        type: Optional[ShieldInformationBarrierSegmentRestrictionBaseTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param shield_information_barrier_segment: The `type` and `id` of the
        requested shield information barrier segment.
                :type shield_information_barrier_segment: ShieldInformationBarrierSegmentRestrictionMiniShieldInformationBarrierSegmentField
                :param restricted_segment: The `type` and `id` of the
        restricted shield information barrier segment.
                :type restricted_segment: ShieldInformationBarrierSegmentRestrictionMiniRestrictedSegmentField
                :param created_at: ISO date time string when this
        shield information barrier
        Segment Restriction object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param updated_at: ISO date time string when this
        shield information barrier segment
        Restriction was updated., defaults to None
                :type updated_at: Optional[DateTime], optional
                :param type: Shield information barrier segment restriction., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentRestrictionBaseTypeField], optional
                :param id: The unique identifier for the
        shield information barrier segment restriction., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(
            shield_information_barrier_segment=shield_information_barrier_segment,
            restricted_segment=restricted_segment,
            type=type,
            id=id,
            **kwargs
        )
        self.shield_information_barrier = shield_information_barrier
        self.created_at = created_at
        self.created_by = created_by
        self.updated_at = updated_at
        self.updated_by = updated_by



from typing import Optional

from box_sdk_gen.schemas.comment_base import CommentBaseTypeField

from box_sdk_gen.schemas.comment_base import CommentBase

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.comment import CommentItemField

from box_sdk_gen.schemas.comment import Comment

from box_sdk_gen.box.errors import BoxSDKError


class CommentFull(Comment):
    def __init__(
        self,
        *,
        tagged_message: Optional[str] = None,
        is_reply_comment: Optional[bool] = None,
        message: Optional[str] = None,
        created_by: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        item: Optional[CommentItemField] = None,
        id: Optional[str] = None,
        type: Optional[CommentBaseTypeField] = None,
        **kwargs
    ):
        """
                :param tagged_message: The string representing the comment text with
        @mentions included. @mention format is @[id:username]
        where `id` is user's Box ID and `username` is
        their display name., defaults to None
                :type tagged_message: Optional[str], optional
                :param is_reply_comment: Whether or not this comment is a reply to another
        comment., defaults to None
                :type is_reply_comment: Optional[bool], optional
                :param message: The text of the comment, as provided by the user., defaults to None
                :type message: Optional[str], optional
                :param created_at: The time this comment was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: The time this comment was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param id: The unique identifier for this comment., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `comment`., defaults to None
                :type type: Optional[CommentBaseTypeField], optional
        """
        super().__init__(
            is_reply_comment=is_reply_comment,
            message=message,
            created_by=created_by,
            created_at=created_at,
            modified_at=modified_at,
            item=item,
            id=id,
            type=type,
            **kwargs
        )
        self.tagged_message = tagged_message



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.keyword_skill_card import KeywordSkillCard

from box_sdk_gen.schemas.timeline_skill_card import TimelineSkillCard

from box_sdk_gen.schemas.transcript_skill_card import TranscriptSkillCard

from box_sdk_gen.schemas.status_skill_card import StatusSkillCard

from box_sdk_gen.schemas.skill_card import SkillCard

from box_sdk_gen.box.errors import BoxSDKError


class SkillCardsMetadata(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'can_edit': '$canEdit',
        'id': '$id',
        'parent': '$parent',
        'scope': '$scope',
        'template': '$template',
        'type': '$type',
        'type_version': '$typeVersion',
        'version': '$version',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        '$canEdit': 'can_edit',
        '$id': 'id',
        '$parent': 'parent',
        '$scope': 'scope',
        '$template': 'template',
        '$type': 'type',
        '$typeVersion': 'type_version',
        '$version': 'version',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        can_edit: Optional[bool] = None,
        id: Optional[str] = None,
        parent: Optional[str] = None,
        scope: Optional[str] = None,
        template: Optional[str] = None,
        type: Optional[str] = None,
        type_version: Optional[int] = None,
        version: Optional[int] = None,
        cards: Optional[List[SkillCard]] = None,
        **kwargs
    ):
        """
                :param can_edit: Whether the user can edit this metadata., defaults to None
                :type can_edit: Optional[bool], optional
                :param id: A UUID to identify the metadata object., defaults to None
                :type id: Optional[str], optional
                :param parent: An ID for the parent folder., defaults to None
                :type parent: Optional[str], optional
                :param scope: An ID for the scope in which this template
        has been applied., defaults to None
                :type scope: Optional[str], optional
                :param template: The name of the template., defaults to None
                :type template: Optional[str], optional
                :param type: A unique identifier for the "type" of this instance. This is an internal
        system property and should not be used by a client application., defaults to None
                :type type: Optional[str], optional
                :param type_version: The last-known version of the template of the object. This is an internal
        system property and should not be used by a client application., defaults to None
                :type type_version: Optional[int], optional
                :param version: The version of the metadata object. Starts at 0 and increases every time
        a user-defined property is modified., defaults to None
                :type version: Optional[int], optional
                :param cards: A list of Box Skill cards that have been applied to this file., defaults to None
                :type cards: Optional[List[SkillCard]], optional
        """
        super().__init__(**kwargs)
        self.can_edit = can_edit
        self.id = id
        self.parent = parent
        self.scope = scope
        self.template = template
        self.type = type
        self.type_version = type_version
        self.version = version
        self.cards = cards



from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.hub_item_operation_result_v2025_r0 import (
    HubItemOperationResultV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class HubItemsManageResponseV2025R0(BaseObject):
    def __init__(self, operations: List[HubItemOperationResultV2025R0], **kwargs):
        """
        :param operations: List of operations performed on Box Hub items.
        :type operations: List[HubItemOperationResultV2025R0]
        """
        super().__init__(**kwargs)
        self.operations = operations



from __future__ import annotations

from typing import TYPE_CHECKING

from enum import Enum

from typing import Optional

from typing import Dict

from typing import List

if TYPE_CHECKING:
    from box_sdk_gen.networking.auth import Authentication

if TYPE_CHECKING:
    from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import ByteStream


class ResponseFormat(str, Enum):
    JSON = 'json'
    BINARY = 'binary'
    NO_CONTENT = 'no_content'


class MultipartItem:
    def __init__(
        self,
        part_name: str,
        *,
        data: Optional[SerializedData] = None,
        file_stream: Optional[ByteStream] = None,
        file_name: Optional[str] = None,
        content_type: Optional[str] = None,
    ):
        """
        :param part_name: Name of the part
        :type part_name: str
        :param data: Data of the part, defaults to None
        :type data: Optional[SerializedData], optional
        :param file_stream: File stream of the part, defaults to None
        :type file_stream: Optional[ByteStream], optional
        :param file_name: File name of the part, defaults to None
        :type file_name: Optional[str], optional
        :param content_type: Content type of the part, defaults to None
        :type content_type: Optional[str], optional
        """
        self.part_name = part_name
        self.data = data
        self.file_stream = file_stream
        self.file_name = file_name
        self.content_type = content_type


class FetchOptions:
    def __init__(
        self,
        url: str,
        method: str,
        *,
        params: Optional[Dict[str, str]] = None,
        headers: Optional[Dict[str, str]] = None,
        data: Optional[SerializedData] = None,
        file_stream: Optional[ByteStream] = None,
        multipart_data: Optional[List[MultipartItem]] = None,
        content_type: str = 'application/json',
        response_format: ResponseFormat = ResponseFormat.JSON,
        auth: Optional[Authentication] = None,
        network_session: Optional[NetworkSession] = None,
        follow_redirects: Optional[bool] = True,
    ):
        """
        :param url: URL of the request
        :type url: str
        :param method: HTTP verb of the request
        :type method: str
        :param params: HTTP query parameters, defaults to None
        :type params: Optional[Dict[str, str]], optional
        :param headers: HTTP headers, defaults to None
        :type headers: Optional[Dict[str, str]], optional
        :param data: Request body of the request, defaults to None
        :type data: Optional[SerializedData], optional
        :param file_stream: Stream data of the request, defaults to None
        :type file_stream: Optional[ByteStream], optional
        :param multipart_data: Multipart data of the request, defaults to None
        :type multipart_data: Optional[List[MultipartItem]], optional
        :param content_type: Content type of the request body, defaults to 'application/json'
        :type content_type: str, optional
        :param response_format: Expected response format, defaults to ResponseFormat.JSON
        :type response_format: ResponseFormat, optional
        :param auth: Authentication object, defaults to None
        :type auth: Optional[Authentication], optional
        :param network_session: Network session object, defaults to None
        :type network_session: Optional[NetworkSession], optional
        :param follow_redirects: A boolean value indicate if the request should follow redirects. Defaults to True. Not supported in Browser environment., defaults to True
        :type follow_redirects: Optional[bool], optional
        """
        self.url = url
        self.method = method
        self.params = params
        self.headers = headers
        self.data = data
        self.file_stream = file_stream
        self.multipart_data = multipart_data
        self.content_type = content_type
        self.response_format = response_format
        self.auth = auth
        self.network_session = network_session
        self.follow_redirects = follow_redirects



from typing import List

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_extract import AiAgentExtract

from box_sdk_gen.schemas.ai_item_base import AiItemBase

from box_sdk_gen.schemas.ai_extract_agent import AiExtractAgent

from box_sdk_gen.box.errors import BoxSDKError


class AiExtract(BaseObject):
    def __init__(
        self,
        prompt: str,
        items: List[AiItemBase],
        *,
        ai_agent: Optional[AiExtractAgent] = None,
        **kwargs
    ):
        """
        :param prompt: The prompt provided to a Large Language Model (LLM) in the request. The prompt can be up to 10000 characters long and it can be an XML or a JSON schema.
        :type prompt: str
        :param items: The items that LLM will process. Currently, you can use files only.
        :type items: List[AiItemBase]
        """
        super().__init__(**kwargs)
        self.prompt = prompt
        self.items = items
        self.ai_agent = ai_agent



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.email_aliases import EmailAliases

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.email_alias import EmailAlias

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class EmailAliasesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_user_email_aliases(
        self, user_id: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> EmailAliases:
        """
                Retrieves all email aliases for a user. The collection

                does not include the primary login for the user.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/email_aliases',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, EmailAliases)

    def create_user_email_alias(
        self,
        user_id: str,
        email: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> EmailAlias:
        """
                Adds a new email alias to a user account..
                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param email: The email address to add to the account as an alias.

        Note: The domain of the email alias needs to be registered
         to your enterprise.
        See the [domain verification guide](
          https://support.box.com/hc/en-us/articles/4408619650579-Domain-Verification
          ) for steps to add a new domain.
                :type email: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'email': email}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/email_aliases',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, EmailAlias)

    def delete_user_email_alias_by_id(
        self,
        user_id: str,
        email_alias_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes an email alias from a user.
                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param email_alias_id: The ID of the email alias.
        Example: "23432"
                :type email_alias_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/email_aliases/',
                        to_string(email_alias_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.sign_request_create_signer import (
    SignRequestCreateSignerRoleField,
)

from box_sdk_gen.schemas.sign_request_create_signer import SignRequestCreateSigner

from box_sdk_gen.schemas.sign_request_signer_input import SignRequestSignerInput

from box_sdk_gen.schemas.sign_request_signer_attachment import (
    SignRequestSignerAttachment,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class SignRequestSignerSignerDecisionTypeField(str, Enum):
    SIGNED = 'signed'
    DECLINED = 'declined'


class SignRequestSignerSignerDecisionField(BaseObject):
    _discriminator = 'type', {'signed', 'declined'}

    def __init__(
        self,
        *,
        type: Optional[SignRequestSignerSignerDecisionTypeField] = None,
        finalized_at: Optional[DateTime] = None,
        additional_info: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: Type of decision made by the signer., defaults to None
        :type type: Optional[SignRequestSignerSignerDecisionTypeField], optional
        :param finalized_at: Date and Time that the decision was made., defaults to None
        :type finalized_at: Optional[DateTime], optional
        :param additional_info: Additional info about the decision, such as the decline reason from the signer., defaults to None
        :type additional_info: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.finalized_at = finalized_at
        self.additional_info = additional_info


class SignRequestSigner(SignRequestCreateSigner):
    def __init__(
        self,
        *,
        has_viewed_document: Optional[bool] = None,
        signer_decision: Optional[SignRequestSignerSignerDecisionField] = None,
        inputs: Optional[List[SignRequestSignerInput]] = None,
        embed_url: Optional[str] = None,
        iframeable_embed_url: Optional[str] = None,
        attachments: Optional[List[SignRequestSignerAttachment]] = None,
        email: Optional[str] = None,
        role: Optional[SignRequestCreateSignerRoleField] = None,
        is_in_person: Optional[bool] = None,
        order: Optional[int] = None,
        embed_url_external_user_id: Optional[str] = None,
        redirect_url: Optional[str] = None,
        declined_redirect_url: Optional[str] = None,
        login_required: Optional[bool] = None,
        verification_phone_number: Optional[str] = None,
        password: Optional[str] = None,
        signer_group_id: Optional[str] = None,
        suppress_notifications: Optional[bool] = None,
        language: Optional[str] = None,
        **kwargs
    ):
        """
                :param has_viewed_document: Set to `true` if the signer views the document., defaults to None
                :type has_viewed_document: Optional[bool], optional
                :param signer_decision: Final decision made by the signer., defaults to None
                :type signer_decision: Optional[SignRequestSignerSignerDecisionField], optional
                :param embed_url: URL to direct a signer to for signing., defaults to None
                :type embed_url: Optional[str], optional
                :param iframeable_embed_url: This URL is specifically designed for
        signing documents within an HTML `iframe` tag.
        It will be returned in the response
        only if the `embed_url_external_user_id`
        parameter was passed in the
        `create Box Sign request` call., defaults to None
                :type iframeable_embed_url: Optional[str], optional
                :param attachments: Attachments that the signer uploaded., defaults to None
                :type attachments: Optional[List[SignRequestSignerAttachment]], optional
                :param email: Email address of the signer.
        The email address of the signer is required when making signature requests, except when using templates that are configured to include emails., defaults to None
                :type email: Optional[str], optional
                :param role: Defines the role of the signer in the signature request. A `signer`
        must sign the document and an `approver` must approve the document. A
        `final_copy_reader` only receives the final signed document and signing
        log., defaults to None
                :type role: Optional[SignRequestCreateSignerRoleField], optional
                :param is_in_person: Used in combination with an embed URL for a sender. After the
        sender signs, they are redirected to the next `in_person` signer., defaults to None
                :type is_in_person: Optional[bool], optional
                :param order: Order of the signer., defaults to None
                :type order: Optional[int], optional
                :param embed_url_external_user_id: User ID for the signer in an external application responsible
        for authentication when accessing the embed URL., defaults to None
                :type embed_url_external_user_id: Optional[str], optional
                :param redirect_url: The URL that a signer will be redirected
        to after signing a document. Defining this URL
        overrides default or global redirect URL
        settings for a specific signer.
        If no declined redirect URL is specified,
        this URL will be used for decline actions as well., defaults to None
                :type redirect_url: Optional[str], optional
                :param declined_redirect_url: The URL that a signer will be redirect
        to after declining to sign a document.
        Defining this URL overrides default or global
        declined redirect URL settings for a specific signer., defaults to None
                :type declined_redirect_url: Optional[str], optional
                :param login_required: If set to true, the signer will need to log in to a Box account
        before signing the request. If the signer does not have
        an existing account, they will have the option to create
        a free Box account., defaults to None
                :type login_required: Optional[bool], optional
                :param verification_phone_number: If set, this phone number will be used to verify the signer
        via two-factor authentication before they are able to sign the document.
        Cannot be selected in combination with `login_required`., defaults to None
                :type verification_phone_number: Optional[str], optional
                :param password: If set, the signer is required to enter the password before they are able
        to sign a document. This field is write only., defaults to None
                :type password: Optional[str], optional
                :param signer_group_id: If set, signers who have the same value will be assigned to the same input and to the same signer group.
        A signer group is not a Box Group. It is an entity that belongs to a Sign Request and can only be
        used/accessed within this Sign Request. A signer group is expected to have more than one signer.
        If the provided value is only used for one signer, this value will be ignored and request will be handled
        as it was intended for an individual signer. The value provided can be any string and only used to
        determine which signers belongs to same group. A successful response will provide a generated UUID value
        instead for signers in the same signer group., defaults to None
                :type signer_group_id: Optional[str], optional
                :param suppress_notifications: If true, no emails about the sign request will be sent., defaults to None
                :type suppress_notifications: Optional[bool], optional
                :param language: The language of the user, formatted in modified version of the
        [ISO 639-1](https://developer.box.com/guides/api-calls/language-codes) format., defaults to None
                :type language: Optional[str], optional
        """
        super().__init__(
            email=email,
            role=role,
            is_in_person=is_in_person,
            order=order,
            embed_url_external_user_id=embed_url_external_user_id,
            redirect_url=redirect_url,
            declined_redirect_url=declined_redirect_url,
            login_required=login_required,
            verification_phone_number=verification_phone_number,
            password=password,
            signer_group_id=signer_group_id,
            suppress_notifications=suppress_notifications,
            language=language,
            **kwargs
        )
        self.has_viewed_document = has_viewed_document
        self.signer_decision = signer_decision
        self.inputs = inputs
        self.embed_url = embed_url
        self.iframeable_embed_url = iframeable_embed_url
        self.attachments = attachments



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.schemas.ai_item_ask import AiItemAsk

from box_sdk_gen.schemas.ai_dialogue_history import AiDialogueHistory

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_ask import AiAgentAsk

from box_sdk_gen.schemas.ai_ask_agent import AiAskAgent

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.ai_agent_text_gen import AiAgentTextGen

from box_sdk_gen.schemas.ai_text_gen_agent import AiTextGenAgent

from box_sdk_gen.schemas.ai_agent_extract import AiAgentExtract

from box_sdk_gen.schemas.ai_agent_extract_structured import AiAgentExtractStructured

from box_sdk_gen.schemas.ai_item_base import AiItemBase

from box_sdk_gen.schemas.ai_extract_agent import AiExtractAgent

from box_sdk_gen.schemas.ai_extract_structured_agent import AiExtractStructuredAgent

from box_sdk_gen.schemas.ai_response_full import AiResponseFull

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.ai_ask import AiAsk

from box_sdk_gen.schemas.ai_response import AiResponse

from box_sdk_gen.schemas.ai_text_gen import AiTextGen

from box_sdk_gen.schemas.ai_agent import AiAgent

from box_sdk_gen.schemas.ai_extract import AiExtract

from box_sdk_gen.schemas.ai_extract_structured_response import (
    AiExtractStructuredResponse,
)

from box_sdk_gen.schemas.ai_extract_structured import AiExtractStructured

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json


class CreateAiAskMode(str, Enum):
    MULTIPLE_ITEM_QA = 'multiple_item_qa'
    SINGLE_ITEM_QA = 'single_item_qa'


class CreateAiTextGenItemsTypeField(str, Enum):
    FILE = 'file'


class CreateAiTextGenItems(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        id: str,
        *,
        type: CreateAiTextGenItemsTypeField = CreateAiTextGenItemsTypeField.FILE,
        content: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The ID of the item.
        :type id: str
        :param type: The type of the item., defaults to CreateAiTextGenItemsTypeField.FILE
        :type type: CreateAiTextGenItemsTypeField, optional
        :param content: The content to use as context for generating new text or editing existing text., defaults to None
        :type content: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.content = content


class GetAiAgentDefaultConfigMode(str, Enum):
    ASK = 'ask'
    TEXT_GEN = 'text_gen'
    EXTRACT = 'extract'
    EXTRACT_STRUCTURED = 'extract_structured'


class CreateAiExtractStructuredMetadataTemplateTypeField(str, Enum):
    METADATA_TEMPLATE = 'metadata_template'


class CreateAiExtractStructuredMetadataTemplate(BaseObject):
    _discriminator = 'type', {'metadata_template'}

    def __init__(
        self,
        *,
        template_key: Optional[str] = None,
        type: Optional[CreateAiExtractStructuredMetadataTemplateTypeField] = None,
        scope: Optional[str] = None,
        **kwargs
    ):
        """
                :param template_key: The name of the metadata template., defaults to None
                :type template_key: Optional[str], optional
                :param type: Value is always `metadata_template`., defaults to None
                :type type: Optional[CreateAiExtractStructuredMetadataTemplateTypeField], optional
                :param scope: The scope of the metadata template that can either be global or
        enterprise.
        * The **global** scope is used for templates that are
        available to any Box enterprise.
        * The **enterprise** scope represents templates created within a specific enterprise,
          containing the ID of that enterprise., defaults to None
                :type scope: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.template_key = template_key
        self.type = type
        self.scope = scope


class CreateAiExtractStructuredFieldsOptionsField(BaseObject):
    def __init__(self, key: str, **kwargs):
        """
        :param key: A unique identifier for the field.
        :type key: str
        """
        super().__init__(**kwargs)
        self.key = key


class CreateAiExtractStructuredFields(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        key: str,
        *,
        description: Optional[str] = None,
        display_name: Optional[str] = None,
        prompt: Optional[str] = None,
        type: Optional[str] = None,
        options: Optional[List[CreateAiExtractStructuredFieldsOptionsField]] = None,
        **kwargs
    ):
        """
        :param key: A unique identifier for the field.
        :type key: str
        :param description: A description of the field., defaults to None
        :type description: Optional[str], optional
        :param display_name: The display name of the field., defaults to None
        :type display_name: Optional[str], optional
        :param prompt: The context about the key that may include how to find and format it., defaults to None
        :type prompt: Optional[str], optional
        :param type: The type of the field. It include but is not limited to string, float, date, enum, and multiSelect., defaults to None
        :type type: Optional[str], optional
        :param options: A list of options for this field. This is most often used in combination with the enum and multiSelect field types., defaults to None
        :type options: Optional[List[CreateAiExtractStructuredFieldsOptionsField]], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.description = description
        self.display_name = display_name
        self.prompt = prompt
        self.type = type
        self.options = options


class AiManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_ai_ask(
        self,
        mode: CreateAiAskMode,
        prompt: str,
        items: List[AiItemAsk],
        *,
        dialogue_history: Optional[List[AiDialogueHistory]] = None,
        include_citations: Optional[bool] = None,
        ai_agent: Optional[AiAskAgent] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[AiResponseFull]:
        """
                Sends an AI request to supported LLMs and returns an answer specifically focused on the user's question given the provided context.
                :param mode: Box AI handles text documents with text representations up to 1MB in size, or a maximum of 25 files,
        whichever comes first. If the text file size exceeds 1MB, the first 1MB of text representation will be processed.
        Box AI handles image documents with a resolution of 1024 x 1024 pixels, with a maximum of 5 images or 5 pages
        for multi-page images. If the number of image or image pages exceeds 5, the first 5 images or pages will
        be processed. If you set mode parameter to `single_item_qa`, the items array can have one element only.
        Currently Box AI does not support multi-modal requests. If both images and text are sent Box AI will only
        process the text.
                :type mode: CreateAiAskMode
                :param prompt: The prompt provided by the client to be answered by the LLM.
        The prompt's length is limited to 10000 characters.
                :type prompt: str
                :param items: The items to be processed by the LLM, often files.
                :type items: List[AiItemAsk]
                :param dialogue_history: The history of prompts and answers previously passed to the LLM. This provides additional context to the LLM in generating the response., defaults to None
                :type dialogue_history: Optional[List[AiDialogueHistory]], optional
                :param include_citations: A flag to indicate whether citations should be returned., defaults to None
                :type include_citations: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'mode': mode,
            'prompt': prompt,
            'items': items,
            'dialogue_history': dialogue_history,
            'include_citations': include_citations,
            'ai_agent': ai_agent,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join([self.network_session.base_urls.base_url, '/2.0/ai/ask']),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '204':
            return None
        return deserialize(response.data, AiResponseFull)

    def create_ai_text_gen(
        self,
        prompt: str,
        items: List[CreateAiTextGenItems],
        *,
        dialogue_history: Optional[List[AiDialogueHistory]] = None,
        ai_agent: Optional[AiTextGenAgent] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiResponse:
        """
                Sends an AI request to supported Large Language Models (LLMs) and returns generated text based on the provided prompt.
                :param prompt: The prompt provided by the client to be answered by the LLM. The prompt's length is limited to 10000 characters.
                :type prompt: str
                :param items: The items to be processed by the LLM, often files.
        The array can include **exactly one** element.

        **Note**: Box AI handles documents with text representations up to 1MB in size.
        If the file size exceeds 1MB, the first 1MB of text representation will be processed.
                :type items: List[CreateAiTextGenItems]
                :param dialogue_history: The history of prompts and answers previously passed to the LLM. This parameter provides the additional context to the LLM when generating the response., defaults to None
                :type dialogue_history: Optional[List[AiDialogueHistory]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'prompt': prompt,
            'items': items,
            'dialogue_history': dialogue_history,
            'ai_agent': ai_agent,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/ai/text_gen']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiResponse)

    def get_ai_agent_default_config(
        self,
        mode: GetAiAgentDefaultConfigMode,
        *,
        language: Optional[str] = None,
        model: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiAgent:
        """
                Get the AI agent default config.
                :param mode: The mode to filter the agent config to return.
                :type mode: GetAiAgentDefaultConfigMode
                :param language: The ISO language code to return the agent config for.
        If the language is not supported the default agent config is returned., defaults to None
                :type language: Optional[str], optional
                :param model: The model to return the default agent config for., defaults to None
                :type model: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'mode': to_string(mode),
                'language': to_string(language),
                'model': to_string(model),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/ai_agent_default']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiAgent)

    def create_ai_extract(
        self,
        prompt: str,
        items: List[AiItemBase],
        *,
        ai_agent: Optional[AiExtractAgent] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiResponse:
        """
        Sends an AI request to supported Large Language Models (LLMs) and extracts metadata in form of key-value pairs.

        In this request, both the prompt and the output can be freeform.


        Metadata template setup before sending the request is not required.

        :param prompt: The prompt provided to a Large Language Model (LLM) in the request. The prompt can be up to 10000 characters long and it can be an XML or a JSON schema.
        :type prompt: str
        :param items: The items that LLM will process. Currently, you can use files only.
        :type items: List[AiItemBase]
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'prompt': prompt, 'items': items, 'ai_agent': ai_agent}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/ai/extract']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiResponse)

    def create_ai_extract_structured(
        self,
        items: List[AiItemBase],
        *,
        metadata_template: Optional[CreateAiExtractStructuredMetadataTemplate] = None,
        fields: Optional[List[CreateAiExtractStructuredFields]] = None,
        include_confidence_score: Optional[bool] = None,
        ai_agent: Optional[AiExtractStructuredAgent] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AiExtractStructuredResponse:
        """
                Sends an AI request to supported Large Language Models (LLMs) and returns extracted metadata as a set of key-value pairs.

                To define the extraction structure, provide either a metadata template or a list of fields. To learn more about creating templates, see [Creating metadata templates in the Admin Console](https://support.box.com/hc/en-us/articles/360044194033-Customizing-Metadata-Templates)


                or use the [metadata template API](https://developer.box.com/guides/metadata/templates/create).


                This endpoint also supports [Enhanced Extract Agent](https://developer.box.com/guides/box-ai/ai-tutorials/extract-metadata-structured#enhanced-extract-agent).


                For information about supported file formats and languages, see the [Extract metadata from file (structured)](https://developer.box.com/guides/box-ai/ai-tutorials/extract-metadata-structured) API guide.

                :param items: The items to be processed by the LLM. Currently you can use files only.
                :type items: List[AiItemBase]
                :param metadata_template: The metadata template containing the fields to extract.
        For your request to work, you must provide either `metadata_template` or `fields`, but not both., defaults to None
                :type metadata_template: Optional[CreateAiExtractStructuredMetadataTemplate], optional
                :param fields: The fields to be extracted from the provided items.
        For your request to work, you must provide either `metadata_template` or `fields`, but not both., defaults to None
                :type fields: Optional[List[CreateAiExtractStructuredFields]], optional
                :param include_confidence_score: A flag to indicate whether confidence scores for every extracted field should be returned., defaults to None
                :type include_confidence_score: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'items': items,
            'metadata_template': metadata_template,
            'fields': fields,
            'include_confidence_score': include_confidence_score,
            'ai_agent': ai_agent,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/ai/extract_structured',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AiExtractStructuredResponse)



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.enterprise_feature_settings_item_v2025_r0 import (
    EnterpriseFeatureSettingsItemV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_string_v2025_r0 import (
    EnterpriseConfigurationItemStringV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_v2025_r0 import (
    EnterpriseConfigurationItemV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.shared_link_permissions_v2025_r0 import (
    SharedLinkPermissionsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_boolean_v2025_r0 import (
    EnterpriseConfigurationItemBooleanV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.collaboration_permissions_v2025_r0 import (
    CollaborationPermissionsV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.list_user_v2025_r0 import ListUserV2025R0

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_integer_v2025_r0 import (
    EnterpriseConfigurationItemIntegerV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseConfigurationContentAndSharingV2025R0SharedLinkDefaultPermissionsSelectedField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[SharedLinkPermissionsV2025R0] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0CollaborationPermissionsField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[CollaborationPermissionsV2025R0] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0CollaborationRestrictionsField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[List[str]] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0ExternalCollaborationStatusField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self, *, value: Optional[str] = None, is_used: Optional[bool] = None, **kwargs
    ):
        """
        :param value: The external collaboration status., defaults to None
        :type value: Optional[str], optional
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0ExternalCollaborationAllowlistUsersField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[List[ListUserV2025R0]] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0PermanentDeletionAllowlistUsersField(
    EnterpriseConfigurationItemV2025R0
):
    def __init__(
        self,
        *,
        value: Optional[List[ListUserV2025R0]] = None,
        is_used: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value


class EnterpriseConfigurationContentAndSharingV2025R0(BaseObject):
    def __init__(
        self,
        *,
        enterprise_feature_settings: Optional[
            List[EnterpriseFeatureSettingsItemV2025R0]
        ] = None,
        sharing_item_type: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        shared_link_company_definition: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        shared_link_access: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        shared_link_default_access: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        shared_link_default_permissions_selected: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0SharedLinkDefaultPermissionsSelectedField
        ] = None,
        is_open_custom_urls_disabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_custom_domain_hidden_in_shared_link: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        collaboration_permissions: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0CollaborationPermissionsField
        ] = None,
        default_collaboration_role: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        is_invite_privilege_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        collaboration_restrictions: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0CollaborationRestrictionsField
        ] = None,
        is_collaborator_invite_links_disabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_invite_group_collaborator_disabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_ownership_transfer_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        external_collaboration_status: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0ExternalCollaborationStatusField
        ] = None,
        external_collaboration_allowlist_users: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0ExternalCollaborationAllowlistUsersField
        ] = None,
        is_watermarking_enterprise_feature_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_root_content_creation_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_tag_creation_restricted: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        tag_creation_restriction: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        is_email_uploads_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_custom_settings_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_forms_login_required: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_forms_branding_default_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_cc_free_trial_active: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_file_request_editors_allowed: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_file_request_branding_default_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_file_request_login_required: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_shared_links_expiration_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        shared_links_expiration_days: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        is_public_shared_links_expiration_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        public_shared_links_expiration_days: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        shared_expiration_target: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        is_shared_links_expiration_notification_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        shared_links_expiration_notification_days: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        is_shared_links_expiration_notification_prevented: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_auto_delete_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        auto_delete_days: Optional[EnterpriseConfigurationItemIntegerV2025R0] = None,
        is_auto_delete_expiration_modification_prevented: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        auto_delete_target: Optional[EnterpriseConfigurationItemStringV2025R0] = None,
        is_collaboration_expiration_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        collaboration_expiration_days: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        is_collaboration_expiration_modification_prevented: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        is_collaboration_expiration_notification_enabled: Optional[
            EnterpriseConfigurationItemBooleanV2025R0
        ] = None,
        collaboration_expiration_target: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        trash_auto_clear_time: Optional[
            EnterpriseConfigurationItemIntegerV2025R0
        ] = None,
        permanent_deletion_access: Optional[
            EnterpriseConfigurationItemStringV2025R0
        ] = None,
        permanent_deletion_allowlist_users: Optional[
            EnterpriseConfigurationContentAndSharingV2025R0PermanentDeletionAllowlistUsersField
        ] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.enterprise_feature_settings = enterprise_feature_settings
        self.sharing_item_type = sharing_item_type
        self.shared_link_company_definition = shared_link_company_definition
        self.shared_link_access = shared_link_access
        self.shared_link_default_access = shared_link_default_access
        self.shared_link_default_permissions_selected = (
            shared_link_default_permissions_selected
        )
        self.is_open_custom_urls_disabled = is_open_custom_urls_disabled
        self.is_custom_domain_hidden_in_shared_link = (
            is_custom_domain_hidden_in_shared_link
        )
        self.collaboration_permissions = collaboration_permissions
        self.default_collaboration_role = default_collaboration_role
        self.is_invite_privilege_restricted = is_invite_privilege_restricted
        self.collaboration_restrictions = collaboration_restrictions
        self.is_collaborator_invite_links_disabled = (
            is_collaborator_invite_links_disabled
        )
        self.is_invite_group_collaborator_disabled = (
            is_invite_group_collaborator_disabled
        )
        self.is_ownership_transfer_restricted = is_ownership_transfer_restricted
        self.external_collaboration_status = external_collaboration_status
        self.external_collaboration_allowlist_users = (
            external_collaboration_allowlist_users
        )
        self.is_watermarking_enterprise_feature_enabled = (
            is_watermarking_enterprise_feature_enabled
        )
        self.is_root_content_creation_restricted = is_root_content_creation_restricted
        self.is_tag_creation_restricted = is_tag_creation_restricted
        self.tag_creation_restriction = tag_creation_restriction
        self.is_email_uploads_enabled = is_email_uploads_enabled
        self.is_custom_settings_enabled = is_custom_settings_enabled
        self.is_forms_login_required = is_forms_login_required
        self.is_forms_branding_default_enabled = is_forms_branding_default_enabled
        self.is_cc_free_trial_active = is_cc_free_trial_active
        self.is_file_request_editors_allowed = is_file_request_editors_allowed
        self.is_file_request_branding_default_enabled = (
            is_file_request_branding_default_enabled
        )
        self.is_file_request_login_required = is_file_request_login_required
        self.is_shared_links_expiration_enabled = is_shared_links_expiration_enabled
        self.shared_links_expiration_days = shared_links_expiration_days
        self.is_public_shared_links_expiration_enabled = (
            is_public_shared_links_expiration_enabled
        )
        self.public_shared_links_expiration_days = public_shared_links_expiration_days
        self.shared_expiration_target = shared_expiration_target
        self.is_shared_links_expiration_notification_enabled = (
            is_shared_links_expiration_notification_enabled
        )
        self.shared_links_expiration_notification_days = (
            shared_links_expiration_notification_days
        )
        self.is_shared_links_expiration_notification_prevented = (
            is_shared_links_expiration_notification_prevented
        )
        self.is_auto_delete_enabled = is_auto_delete_enabled
        self.auto_delete_days = auto_delete_days
        self.is_auto_delete_expiration_modification_prevented = (
            is_auto_delete_expiration_modification_prevented
        )
        self.auto_delete_target = auto_delete_target
        self.is_collaboration_expiration_enabled = is_collaboration_expiration_enabled
        self.collaboration_expiration_days = collaboration_expiration_days
        self.is_collaboration_expiration_modification_prevented = (
            is_collaboration_expiration_modification_prevented
        )
        self.is_collaboration_expiration_notification_enabled = (
            is_collaboration_expiration_notification_enabled
        )
        self.collaboration_expiration_target = collaboration_expiration_target
        self.trash_auto_clear_time = trash_auto_clear_time
        self.permanent_deletion_access = permanent_deletion_access
        self.permanent_deletion_allowlist_users = permanent_deletion_allowlist_users



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.session_termination_message import SessionTerminationMessage

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData


class SessionTerminationManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def terminate_users_sessions(
        self,
        user_ids: List[str],
        user_logins: List[str],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SessionTerminationMessage:
        """
        Validates the roles and permissions of the user,

        and creates asynchronous jobs


        to terminate the user's sessions.


        Returns the status for the POST request.

        :param user_ids: A list of user IDs.
        :type user_ids: List[str]
        :param user_logins: A list of user logins.
        :type user_logins: List[str]
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'user_ids': user_ids, 'user_logins': user_logins}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/terminate_sessions',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SessionTerminationMessage)

    def terminate_groups_sessions(
        self,
        group_ids: List[str],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> SessionTerminationMessage:
        """
        Validates the roles and permissions of the group,

        and creates asynchronous jobs


        to terminate the group's sessions.


        Returns the status for the POST request.

        :param group_ids: A list of group IDs.
        :type group_ids: List[str]
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'group_ids': group_ids}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/groups/terminate_sessions',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, SessionTerminationMessage)



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class HubCopyRequestV2025R0(BaseObject):
    def __init__(
        self,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        **kwargs
    ):
        """
        :param title: Title of the Box Hub. It cannot be empty and should be less than 50 characters., defaults to None
        :type title: Optional[str], optional
        :param description: Description of the Box Hub., defaults to None
        :type description: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.title = title
        self.description = description



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListContentIpV2025R0TypeField(str, Enum):
    IP = 'ip'


class ShieldListContentIpV2025R0(BaseObject):
    _discriminator = 'type', {'ip'}

    def __init__(
        self,
        ip_addresses: List[str],
        *,
        type: ShieldListContentIpV2025R0TypeField = ShieldListContentIpV2025R0TypeField.IP,
        **kwargs
    ):
        """
        :param ip_addresses: List of ip addresses and CIDRs.
        :type ip_addresses: List[str]
        :param type: The type of content in the shield list., defaults to ShieldListContentIpV2025R0TypeField.IP
        :type type: ShieldListContentIpV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.ip_addresses = ip_addresses
        self.type = type



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from box_sdk_gen.box.errors import BoxSDKError


class ArchiveV2025R0TypeField(str, Enum):
    ARCHIVE = 'archive'


class ArchiveV2025R0OwnedByField(BaseObject):
    def __init__(self, id: str, type: str, **kwargs):
        """
        :param id: The unique identifier that represents a user who owns the archive.
        :type id: str
        :param type: The value is always `user`.
        :type type: str
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class ArchiveV2025R0(BaseObject):
    _discriminator = 'type', {'archive'}

    def __init__(
        self,
        id: str,
        name: str,
        size: int,
        *,
        type: ArchiveV2025R0TypeField = ArchiveV2025R0TypeField.ARCHIVE,
        description: Optional[str] = None,
        owned_by: Optional[ArchiveV2025R0OwnedByField] = None,
        **kwargs
    ):
        r"""
                :param id: The unique identifier that represents an archive.
                :type id: str
                :param name: The name of the archive.

        The following restrictions to the archive name apply: names containing
        non-printable ASCII characters, forward and backward slashes
        (`/`, `\`), names with trailing spaces, and names `.` and `..` are
        not allowed.
                :type name: str
                :param size: The size of the archive in bytes.
                :type size: int
                :param type: The value is always `archive`., defaults to ArchiveV2025R0TypeField.ARCHIVE
                :type type: ArchiveV2025R0TypeField, optional
                :param description: The description of the archive., defaults to None
                :type description: Optional[str], optional
                :param owned_by: The part of an archive API response that describes the user who owns the archive., defaults to None
                :type owned_by: Optional[ArchiveV2025R0OwnedByField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.name = name
        self.size = size
        self.type = type
        self.description = description
        self.owned_by = owned_by



from typing import Union

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_text_gen import AiAgentTextGen

from box_sdk_gen.box.errors import BoxSDKError

AiTextGenAgent = Union[AiAgentReference, AiAgentTextGen]



from typing import Optional

from box_sdk_gen.schemas.v2025_r0.hub_base_v2025_r0 import HubBaseV2025R0TypeField

from box_sdk_gen.schemas.v2025_r0.hub_base_v2025_r0 import HubBaseV2025R0

from box_sdk_gen.schemas.v2025_r0.user_mini_v2025_r0 import UserMiniV2025R0

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class HubV2025R0(HubBaseV2025R0):
    def __init__(
        self,
        id: str,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        updated_at: Optional[DateTime] = None,
        created_by: Optional[UserMiniV2025R0] = None,
        updated_by: Optional[UserMiniV2025R0] = None,
        view_count: Optional[int] = None,
        is_ai_enabled: Optional[bool] = None,
        is_collaboration_restricted_to_enterprise: Optional[bool] = None,
        can_non_owners_invite: Optional[bool] = None,
        can_shared_link_be_created: Optional[bool] = None,
        can_public_shared_link_be_created: Optional[bool] = None,
        type: HubBaseV2025R0TypeField = HubBaseV2025R0TypeField.HUBS,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a Box Hub.

        The ID for any Box Hub can be determined
        by visiting a Box Hub in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/hubs/123`
        the `hub_id` is `123`.
                :type id: str
                :param title: The title given to the Box Hub., defaults to None
                :type title: Optional[str], optional
                :param description: The description of the Box Hub. First 200 characters are returned., defaults to None
                :type description: Optional[str], optional
                :param created_at: The date and time when the folder was created. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type created_at: Optional[DateTime], optional
                :param updated_at: The date and time when the Box Hub was last updated., defaults to None
                :type updated_at: Optional[DateTime], optional
                :param view_count: The number of views for the Box Hub., defaults to None
                :type view_count: Optional[int], optional
                :param is_ai_enabled: Indicates if AI features are enabled for the Box Hub., defaults to None
                :type is_ai_enabled: Optional[bool], optional
                :param is_collaboration_restricted_to_enterprise: Indicates if collaboration is restricted to the enterprise., defaults to None
                :type is_collaboration_restricted_to_enterprise: Optional[bool], optional
                :param can_non_owners_invite: Indicates if non-owners can invite others to the Box Hub., defaults to None
                :type can_non_owners_invite: Optional[bool], optional
                :param can_shared_link_be_created: Indicates if a shared link can be created for the Box Hub., defaults to None
                :type can_shared_link_be_created: Optional[bool], optional
                :param can_public_shared_link_be_created: Indicates if a public shared link can be created for the Box Hub., defaults to None
                :type can_public_shared_link_be_created: Optional[bool], optional
                :param type: The value will always be `hubs`., defaults to HubBaseV2025R0TypeField.HUBS
                :type type: HubBaseV2025R0TypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.title = title
        self.description = description
        self.created_at = created_at
        self.updated_at = updated_at
        self.created_by = created_by
        self.updated_by = updated_by
        self.view_count = view_count
        self.is_ai_enabled = is_ai_enabled
        self.is_collaboration_restricted_to_enterprise = (
            is_collaboration_restricted_to_enterprise
        )
        self.can_non_owners_invite = can_non_owners_invite
        self.can_shared_link_be_created = can_shared_link_be_created
        self.can_public_shared_link_be_created = can_public_shared_link_be_created



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.terms_of_service_user_statuses import (
    TermsOfServiceUserStatuses,
)

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.terms_of_service_user_status import TermsOfServiceUserStatus

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateTermsOfServiceStatusForUserTosTypeField(str, Enum):
    TERMS_OF_SERVICE = 'terms_of_service'


class CreateTermsOfServiceStatusForUserTos(BaseObject):
    _discriminator = 'type', {'terms_of_service'}

    def __init__(
        self,
        id: str,
        *,
        type: CreateTermsOfServiceStatusForUserTosTypeField = CreateTermsOfServiceStatusForUserTosTypeField.TERMS_OF_SERVICE,
        **kwargs
    ):
        """
        :param id: The ID of terms of service.
        :type id: str
        :param type: The type of object., defaults to CreateTermsOfServiceStatusForUserTosTypeField.TERMS_OF_SERVICE
        :type type: CreateTermsOfServiceStatusForUserTosTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CreateTermsOfServiceStatusForUserUserTypeField(str, Enum):
    USER = 'user'


class CreateTermsOfServiceStatusForUserUser(BaseObject):
    _discriminator = 'type', {'user'}

    def __init__(
        self,
        id: str,
        *,
        type: CreateTermsOfServiceStatusForUserUserTypeField = CreateTermsOfServiceStatusForUserUserTypeField.USER,
        **kwargs
    ):
        """
        :param id: The ID of user.
        :type id: str
        :param type: The type of object., defaults to CreateTermsOfServiceStatusForUserUserTypeField.USER
        :type type: CreateTermsOfServiceStatusForUserUserTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class TermsOfServiceUserStatusesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_terms_of_service_user_statuses(
        self,
        tos_id: str,
        *,
        user_id: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfServiceUserStatuses:
        """
        Retrieves an overview of users and their status for a

        terms of service, including Whether they have accepted


        the terms and when.

        :param tos_id: The ID of the terms of service.
        :type tos_id: str
        :param user_id: Limits results to the given user ID., defaults to None
        :type user_id: Optional[str], optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'tos_id': to_string(tos_id), 'user_id': to_string(user_id)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/terms_of_service_user_statuses',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfServiceUserStatuses)

    def create_terms_of_service_status_for_user(
        self,
        tos: CreateTermsOfServiceStatusForUserTos,
        user: CreateTermsOfServiceStatusForUserUser,
        is_accepted: bool,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfServiceUserStatus:
        """
        Sets the status for a terms of service for a user.
        :param tos: The terms of service to set the status for.
        :type tos: CreateTermsOfServiceStatusForUserTos
        :param user: The user to set the status for.
        :type user: CreateTermsOfServiceStatusForUserUser
        :param is_accepted: Whether the user has accepted the terms.
        :type is_accepted: bool
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'tos': tos, 'user': user, 'is_accepted': is_accepted}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/terms_of_service_user_statuses',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfServiceUserStatus)

    def update_terms_of_service_status_for_user_by_id(
        self,
        terms_of_service_user_status_id: str,
        is_accepted: bool,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> TermsOfServiceUserStatus:
        """
                Updates the status for a terms of service for a user.
                :param terms_of_service_user_status_id: The ID of the terms of service status.
        Example: "324234"
                :type terms_of_service_user_status_id: str
                :param is_accepted: Whether the user has accepted the terms.
                :type is_accepted: bool
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'is_accepted': is_accepted}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/terms_of_service_user_statuses/',
                        to_string(terms_of_service_user_status_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, TermsOfServiceUserStatus)



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.app_item import AppItem

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class SharedLinksAppItemsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def find_app_item_for_shared_link(
        self, boxapi: str, *, extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> AppItem:
        """
                Returns the app item represented by a shared link.

                The link can originate from the current enterprise or another.

                :param boxapi: A header containing the shared link and optional password for the
        shared link.

        The format for this header is `shared_link=[link]&shared_link_password=[password]`.
                :type boxapi: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'boxapi': to_string(boxapi), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/shared_items#app_items',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, AppItem)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_extract_structured import AiAgentExtractStructured

from box_sdk_gen.schemas.ai_item_base import AiItemBase

from box_sdk_gen.schemas.ai_extract_structured_agent import AiExtractStructuredAgent

from box_sdk_gen.box.errors import BoxSDKError


class AiExtractStructuredMetadataTemplateTypeField(str, Enum):
    METADATA_TEMPLATE = 'metadata_template'


class AiExtractStructuredMetadataTemplateField(BaseObject):
    _discriminator = 'type', {'metadata_template'}

    def __init__(
        self,
        *,
        template_key: Optional[str] = None,
        type: Optional[AiExtractStructuredMetadataTemplateTypeField] = None,
        scope: Optional[str] = None,
        **kwargs
    ):
        """
                :param template_key: The name of the metadata template., defaults to None
                :type template_key: Optional[str], optional
                :param type: Value is always `metadata_template`., defaults to None
                :type type: Optional[AiExtractStructuredMetadataTemplateTypeField], optional
                :param scope: The scope of the metadata template that can either be global or
        enterprise.
        * The **global** scope is used for templates that are
        available to any Box enterprise.
        * The **enterprise** scope represents templates created within a specific enterprise,
          containing the ID of that enterprise., defaults to None
                :type scope: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.template_key = template_key
        self.type = type
        self.scope = scope


class AiExtractStructuredFieldsOptionsField(BaseObject):
    def __init__(self, key: str, **kwargs):
        """
        :param key: A unique identifier for the field.
        :type key: str
        """
        super().__init__(**kwargs)
        self.key = key


class AiExtractStructuredFieldsField(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'display_name': 'displayName',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'displayName': 'display_name',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        key: str,
        *,
        description: Optional[str] = None,
        display_name: Optional[str] = None,
        prompt: Optional[str] = None,
        type: Optional[str] = None,
        options: Optional[List[AiExtractStructuredFieldsOptionsField]] = None,
        **kwargs
    ):
        """
        :param key: A unique identifier for the field.
        :type key: str
        :param description: A description of the field., defaults to None
        :type description: Optional[str], optional
        :param display_name: The display name of the field., defaults to None
        :type display_name: Optional[str], optional
        :param prompt: The context about the key that may include how to find and format it., defaults to None
        :type prompt: Optional[str], optional
        :param type: The type of the field. It include but is not limited to string, float, date, enum, and multiSelect., defaults to None
        :type type: Optional[str], optional
        :param options: A list of options for this field. This is most often used in combination with the enum and multiSelect field types., defaults to None
        :type options: Optional[List[AiExtractStructuredFieldsOptionsField]], optional
        """
        super().__init__(**kwargs)
        self.key = key
        self.description = description
        self.display_name = display_name
        self.prompt = prompt
        self.type = type
        self.options = options


class AiExtractStructured(BaseObject):
    def __init__(
        self,
        items: List[AiItemBase],
        *,
        metadata_template: Optional[AiExtractStructuredMetadataTemplateField] = None,
        fields: Optional[List[AiExtractStructuredFieldsField]] = None,
        include_confidence_score: Optional[bool] = None,
        ai_agent: Optional[AiExtractStructuredAgent] = None,
        **kwargs
    ):
        """
                :param items: The items to be processed by the LLM. Currently you can use files only.
                :type items: List[AiItemBase]
                :param metadata_template: The metadata template containing the fields to extract.
        For your request to work, you must provide either `metadata_template` or `fields`, but not both., defaults to None
                :type metadata_template: Optional[AiExtractStructuredMetadataTemplateField], optional
                :param fields: The fields to be extracted from the provided items.
        For your request to work, you must provide either `metadata_template` or `fields`, but not both., defaults to None
                :type fields: Optional[List[AiExtractStructuredFieldsField]], optional
                :param include_confidence_score: A flag to indicate whether confidence scores for every extracted field should be returned., defaults to None
                :type include_confidence_score: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.items = items
        self.metadata_template = metadata_template
        self.fields = fields
        self.include_confidence_score = include_confidence_score
        self.ai_agent = ai_agent



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TranscriptSkillCardTypeField(str, Enum):
    SKILL_CARD = 'skill_card'


class TranscriptSkillCardSkillCardTypeField(str, Enum):
    TRANSCRIPT = 'transcript'


class TranscriptSkillCardSkillCardTitleField(BaseObject):
    def __init__(self, message: str, *, code: Optional[str] = None, **kwargs):
        """
        :param message: The actual title to show in the UI.
        :type message: str
        :param code: An optional identifier for the title., defaults to None
        :type code: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.message = message
        self.code = code


class TranscriptSkillCardSkillTypeField(str, Enum):
    SERVICE = 'service'


class TranscriptSkillCardSkillField(BaseObject):
    _discriminator = 'type', {'service'}

    def __init__(
        self,
        id: str,
        *,
        type: TranscriptSkillCardSkillTypeField = TranscriptSkillCardSkillTypeField.SERVICE,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the service that
        applied this metadata.
                :type id: str
                :param type: The value will always be `service`., defaults to TranscriptSkillCardSkillTypeField.SERVICE
                :type type: TranscriptSkillCardSkillTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class TranscriptSkillCardInvocationTypeField(str, Enum):
    SKILL_INVOCATION = 'skill_invocation'


class TranscriptSkillCardInvocationField(BaseObject):
    _discriminator = 'type', {'skill_invocation'}

    def __init__(
        self,
        id: str,
        *,
        type: TranscriptSkillCardInvocationTypeField = TranscriptSkillCardInvocationTypeField.SKILL_INVOCATION,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the instance of
        the service that applied this metadata. For example,
        if your `image-recognition-service` runs on multiple
        nodes, this field can be used to identify the ID of
        the node that was used to apply the metadata.
                :type id: str
                :param type: The value will always be `skill_invocation`., defaults to TranscriptSkillCardInvocationTypeField.SKILL_INVOCATION
                :type type: TranscriptSkillCardInvocationTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class TranscriptSkillCardEntriesAppearsField(BaseObject):
    def __init__(self, *, start: Optional[int] = None, **kwargs):
        """
                :param start: The time in seconds when an
        entry should start appearing on a timeline., defaults to None
                :type start: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.start = start


class TranscriptSkillCardEntriesField(BaseObject):
    def __init__(
        self,
        *,
        text: Optional[str] = None,
        appears: Optional[List[TranscriptSkillCardEntriesAppearsField]] = None,
        **kwargs
    ):
        """
                :param text: The text of the entry. This would be the transcribed text assigned
        to the entry on the timeline., defaults to None
                :type text: Optional[str], optional
                :param appears: Defines when a transcribed bit of text appears. This only includes a
        start time and no end time., defaults to None
                :type appears: Optional[List[TranscriptSkillCardEntriesAppearsField]], optional
        """
        super().__init__(**kwargs)
        self.text = text
        self.appears = appears


class TranscriptSkillCard(BaseObject):
    _discriminator = 'skill_card_type', {'transcript'}

    def __init__(
        self,
        skill: TranscriptSkillCardSkillField,
        invocation: TranscriptSkillCardInvocationField,
        entries: List[TranscriptSkillCardEntriesField],
        *,
        created_at: Optional[DateTime] = None,
        type: TranscriptSkillCardTypeField = TranscriptSkillCardTypeField.SKILL_CARD,
        skill_card_type: TranscriptSkillCardSkillCardTypeField = TranscriptSkillCardSkillCardTypeField.TRANSCRIPT,
        skill_card_title: Optional[TranscriptSkillCardSkillCardTitleField] = None,
        duration: Optional[int] = None,
        **kwargs
    ):
        """
                :param skill: The service that applied this metadata.
                :type skill: TranscriptSkillCardSkillField
                :param invocation: The invocation of this service, used to track
        which instance of a service applied the metadata.
                :type invocation: TranscriptSkillCardInvocationField
                :param entries: An list of entries for the card. This represents the individual entries of
        the transcription.
                :type entries: List[TranscriptSkillCardEntriesField]
                :param created_at: The optional date and time this card was created at., defaults to None
                :type created_at: Optional[DateTime], optional
                :param type: The value will always be `skill_card`., defaults to TranscriptSkillCardTypeField.SKILL_CARD
                :type type: TranscriptSkillCardTypeField, optional
                :param skill_card_type: The value will always be `transcript`., defaults to TranscriptSkillCardSkillCardTypeField.TRANSCRIPT
                :type skill_card_type: TranscriptSkillCardSkillCardTypeField, optional
                :param skill_card_title: The title of the card., defaults to None
                :type skill_card_title: Optional[TranscriptSkillCardSkillCardTitleField], optional
                :param duration: An optional total duration in seconds.

        Used with a `skill_card_type` of `transcript` or
        `timeline`., defaults to None
                :type duration: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.skill = skill
        self.invocation = invocation
        self.entries = entries
        self.created_at = created_at
        self.type = type
        self.skill_card_type = skill_card_type
        self.skill_card_title = skill_card_title
        self.duration = duration



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.retention_policy_assignments import RetentionPolicyAssignments

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.retention_policy_assignment import RetentionPolicyAssignment

from box_sdk_gen.schemas.files_under_retention import FilesUnderRetention

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetRetentionPolicyAssignmentsType(str, Enum):
    FOLDER = 'folder'
    ENTERPRISE = 'enterprise'
    METADATA_TEMPLATE = 'metadata_template'


class CreateRetentionPolicyAssignmentAssignToTypeField(str, Enum):
    ENTERPRISE = 'enterprise'
    FOLDER = 'folder'
    METADATA_TEMPLATE = 'metadata_template'


class CreateRetentionPolicyAssignmentAssignTo(BaseObject):
    _discriminator = 'type', {'enterprise', 'folder', 'metadata_template'}

    def __init__(
        self,
        type: CreateRetentionPolicyAssignmentAssignToTypeField,
        *,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of item to assign the policy to.
                :type type: CreateRetentionPolicyAssignmentAssignToTypeField
                :param id: The ID of item to assign the policy to.
        Set to `null` or omit when `type` is set to
        `enterprise`., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class CreateRetentionPolicyAssignmentFilterFields(BaseObject):
    def __init__(
        self, *, field: Optional[str] = None, value: Optional[str] = None, **kwargs
    ):
        """
                :param field: The metadata attribute key id., defaults to None
                :type field: Optional[str], optional
                :param value: The metadata attribute field id. For value, only
        enum and multiselect types are supported., defaults to None
                :type value: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.field = field
        self.value = value


class RetentionPolicyAssignmentsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_retention_policy_assignments(
        self,
        retention_policy_id: str,
        *,
        type: Optional[GetRetentionPolicyAssignmentsType] = None,
        fields: Optional[List[str]] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicyAssignments:
        """
                Returns a list of all retention policy assignments associated with a specified

                retention policy.

                :param retention_policy_id: The ID of the retention policy.
        Example: "982312"
                :type retention_policy_id: str
                :param type: The type of the retention policy assignment to retrieve., defaults to None
                :type type: Optional[GetRetentionPolicyAssignmentsType], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'type': to_string(type),
                'fields': to_string(fields),
                'marker': to_string(marker),
                'limit': to_string(limit),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policies/',
                        to_string(retention_policy_id),
                        '/assignments',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicyAssignments)

    def create_retention_policy_assignment(
        self,
        policy_id: str,
        assign_to: CreateRetentionPolicyAssignmentAssignTo,
        *,
        filter_fields: Optional[
            List[CreateRetentionPolicyAssignmentFilterFields]
        ] = None,
        start_date_field: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicyAssignment:
        """
                Assigns a retention policy to an item.
                :param policy_id: The ID of the retention policy to assign.
                :type policy_id: str
                :param assign_to: The item to assign the policy to.
                :type assign_to: CreateRetentionPolicyAssignmentAssignTo
                :param filter_fields: If the `assign_to` type is `metadata_template`,
        then optionally add the `filter_fields` parameter which will
        require an array of objects with a field entry and a value entry.
        Currently only one object of `field` and `value` is supported., defaults to None
                :type filter_fields: Optional[List[CreateRetentionPolicyAssignmentFilterFields]], optional
                :param start_date_field: The date the retention policy assignment begins.

        If the `assigned_to` type is `metadata_template`,
        this field can be a date field's metadata attribute key id., defaults to None
                :type start_date_field: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'policy_id': policy_id,
            'assign_to': assign_to,
            'filter_fields': filter_fields,
            'start_date_field': start_date_field,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policy_assignments',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicyAssignment)

    def get_retention_policy_assignment_by_id(
        self,
        retention_policy_assignment_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicyAssignment:
        """
                Retrieves a retention policy assignment.
                :param retention_policy_assignment_id: The ID of the retention policy assignment.
        Example: "1233123"
                :type retention_policy_assignment_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policy_assignments/',
                        to_string(retention_policy_assignment_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicyAssignment)

    def delete_retention_policy_assignment_by_id(
        self,
        retention_policy_assignment_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes a retention policy assignment

                applied to content.

                :param retention_policy_assignment_id: The ID of the retention policy assignment.
        Example: "1233123"
                :type retention_policy_assignment_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policy_assignments/',
                        to_string(retention_policy_assignment_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_files_under_retention_policy_assignment(
        self,
        retention_policy_assignment_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FilesUnderRetention:
        """
                Returns a list of files under retention for a retention policy assignment.
                :param retention_policy_assignment_id: The ID of the retention policy assignment.
        Example: "1233123"
                :type retention_policy_assignment_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'marker': to_string(marker), 'limit': to_string(limit)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policy_assignments/',
                        to_string(retention_policy_assignment_id),
                        '/files_under_retention',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FilesUnderRetention)



from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class BaseUrls(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'oauth_2_url': 'oauth2_url',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'oauth2_url': 'oauth_2_url',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        base_url: str = 'https://api.box.com',
        upload_url: str = 'https://upload.box.com/api',
        oauth_2_url: str = 'https://account.box.com/api/oauth2',
        **kwargs
    ):
        super().__init__(**kwargs)
        self.base_url = base_url
        self.upload_url = upload_url
        self.oauth_2_url = oauth_2_url
